@@ -571,7 +571,7 @@ getRefV8 (GnmCellRef *cr,
 static void
 parse_list_push (GnmExprList **list, GnmExpr const *pd)
 {
-	d (5, fprintf (stderr, "Push 0x%p\n", pd););
+	d (5, fprintf (stderr, "Push 0x%p\n", (void *)pd););
 	if (pd == NULL) {
 		g_warning ("FIXME: Pushing nothing onto excel function stack");
 		pd = xl_expr_err (NULL, -1, -1,
@@ -595,7 +595,7 @@ parse_list_pop (GnmExprList **list)
 	if (tmp != NULL) {
 		GnmExpr const *ans = tmp->data;
 		*list = g_slist_remove (*list, ans);
-		d (5, fprintf (stderr, "Pop 0x%p\n", ans););
+		d (5, fprintf (stderr, "Pop 0x%p\n", (void *)ans););
 		return ans;
 	}
 
@@ -755,6 +755,7 @@ static GnmExprOp const unary_ops [] = {
 	GNM_EXPR_OP_UNARY_PLUS,/* 0x12, ptgU_PLUS  */
 	GNM_EXPR_OP_UNARY_NEG,	/* 0x13, ptgU_MINUS */
 	GNM_EXPR_OP_PERCENTAGE,	/* 0x14, ptgPERCENT */
+	GNM_EXPR_OP_PAREN,      /* 0x15, pgtPAREN */
 };
 
 static gboolean
@@ -1049,16 +1050,12 @@ excel_parse_formula1 (MSContainer const *container,
 		case FORMULA_PTG_U_PLUS :
 		case FORMULA_PTG_U_MINUS :
 		case FORMULA_PTG_PERCENT :
+		case FORMULA_PTG_PAREN:
 			parse_list_push (&stack, gnm_expr_new_unary (
 				unary_ops [ptgbase - FORMULA_PTG_U_PLUS],
 				parse_list_pop (&stack)));
 			break;
 
-		case FORMULA_PTG_PAREN:
-/*	  fprintf (stderr, "Ignoring redundant parenthesis ptg\n"); */
-			ptg_length = 0;
-			break;
-
 		case FORMULA_PTG_MISSARG:
 			parse_list_push_raw (&stack, value_new_empty ());
 			ptg_length = 0;
@@ -1462,7 +1459,7 @@ excel_parse_formula1 (MSContainer const *container,
 				} else
 				{
 					g_warning ("EXCEL: %x (of %x) UNKNOWN name %p.",
-						   name_idx, names ? names->len : 0xffffffff, container);
+						   name_idx, names ? names->len : 0xffffffff, (void *)container);
 					name = gnm_expr_new_constant (
 						value_new_error_NAME (NULL));
 				}
@@ -1595,7 +1592,7 @@ excel_parse_formula1 (MSContainer const *container,
 			if (names == NULL || name_idx < 1 || names->len < name_idx ||
 			    (nexpr = g_ptr_array_index (names, name_idx-1)) == NULL) {
 				g_warning ("EXCEL: %x (of %x) UNKNOWN name %p.",
-					   name_idx, names ? names->len : 0xffffffff, container);
+					   name_idx, names ? names->len : 0xffffffff, (void *)container);
 				name = gnm_expr_new_constant (
 					value_new_error_REF (NULL));
 			} else {
