@@ -645,7 +645,9 @@ value_intersection (GnmValue *v, GnmEvalPos const *pos)
 	gboolean found = FALSE;
 
 	if (v->type == VALUE_ARRAY) {
-		res = value_dup (v->v_array.vals[0][0]);
+		res = (v->v_array.x == 0 || v->v_array.y == 0)
+			? value_new_error_VALUE (NULL)
+			: value_dup (v->v_array.vals[0][0]);
 		value_release (v);
 		return res;
 	}
@@ -1225,6 +1227,9 @@ gnm_expr_eval (GnmExpr const *expr, GnmEvalPos const *pos,
 		value_release (b);
 		return res;
 
+	case GNM_EXPR_OP_PAREN:
+		return gnm_expr_eval (expr->unary.value, pos, flags);
+
 	case GNM_EXPR_OP_PERCENTAGE:
 	case GNM_EXPR_OP_UNARY_NEG:
 	case GNM_EXPR_OP_UNARY_PLUS:
@@ -1476,6 +1481,7 @@ do_expr_as_string (GnmExpr const *expr, int paren_level,
 		guint8 assoc_left, assoc_right;  /* 0: no, 1: yes.  */
 		guint8 is_prefix;                /* for unary operators */
 	} const operations[] = {
+		{ "",   0, 0, 0, 0 }, /* Parentheses for clarity */
 		{ "=",  1, 1, 0, 0 },
 		{ ">",  1, 1, 0, 0 },
 		{ "<",  1, 1, 0, 0 },
@@ -3033,7 +3039,7 @@ cb_expression_pool_leak (gpointer data, G_GNUC_UNUSED gpointer user)
 	pp.sheet = NULL;
 	pp.wb = NULL;
 	s = gnm_expr_as_string (expr, &pp, gnm_conventions_default);
-	g_printerr ("Leaking expression at %p: %s.\n", expr, s);
+	g_printerr ("Leaking expression at %p: %s.\n", (void *)expr, s);
 	g_free (s);
 }
 #endif
