@@ -2146,7 +2146,7 @@ yyreduce:
 		} else {
 			if ((yyvsp[(2) - (3)].list)->next == NULL) {
 				unregister_allocation ((yyvsp[(2) - (3)].list));
-				(yyval.expr) = register_expr_allocation ((yyvsp[(2) - (3)].list)->data);
+				(yyval.expr) = register_expr_allocation (gnm_expr_new_unary (GNM_EXPR_OP_PAREN, (yyvsp[(2) - (3)].list)->data));
 				/* NOTE : free list not content */
 				gnm_expr_list_free ((yyvsp[(2) - (3)].list));
 			} else {
